@@ -52,7 +52,7 @@ stopwords = {
     'while', 'o', 'themselves', 'youd', 'each', 't', 'just', 'their', 'm',
     'won', 'hers', 'who', 'by', 'does', 'above', 'hadn', 'more', 'we',
     'weren', 'had', 'couldnt', 'is', 'or', 'an', 'needn', 'y', 'further',
-    'now', 'you', 'how', 'against', 'those', 'can', 'here', 'has', 'theirs',
+    'now', 'you', 'against', 'those', 'can', 'here', 'has', 'theirs',
     'with', 'yourselves', 'the', 'wasnt', 'havent', 'whom', 'do', 'other',
     'shouldn'
 }
@@ -451,11 +451,8 @@ class IndexGenerator:
         content = content.lower().replace('_', ' ').replace('.', ' ')
         content = self.remover.sub('', content)
 
-        # Remove stopwords.
-        content = [word for word in content.split()]
-
         # Count occurrences of words in page.
-        word_counter = Counter(content)
+        word_counter = Counter(content.split())
 
         # Get the index of the current page and update the list.
         i = len(self.urltitles)
@@ -465,7 +462,7 @@ class IndexGenerator:
         for word, count in sorted(word_counter.items(), key=lambda x: x[1]):
             self.trie.insert(word, i, int(count * priority))
 
-    def build(self, temp_path: Path, dest_path: Path):
+    def build(self, temp_path: Path, dest_path: Path, build_local: bool):
         """Write the search index file to the destination directory.
 
         Parameters
@@ -491,7 +488,6 @@ class IndexGenerator:
         template = Template((source_path / 'search.h.jinja').read_text())
 
         # Write the search index to header.
-        temp_path = temp_path / 'search'
         temp_path.mkdir(parents=True, exist_ok=True)
         with open(temp_path / 'search.h', 'w') as f:
             f.write('/*=== AUTOMATICALLY GENERATED FILE ===*/\n\n')
@@ -516,8 +512,7 @@ class IndexGenerator:
         if shutil.which(wasm_linker) is None:
             wasm_linker = '/usr/lib/llvm-10/bin/wasm-ld'
         if shutil.which(wasm_linker) is None:
-            print('wasm-ld is not found! You should probably '
-                  'install it (TODO: better message)')
+            print('wasm-ld is not found, the search index could not be build!')
 
         # Link the object file to create a usable webassembly binary.
         cmnd = [wasm_linker, '--no-entry',
@@ -525,3 +520,15 @@ class IndexGenerator:
                 f'{object_file}']
         dest_path.mkdir(parents=True, exist_ok=True)
         os.system(' '.join(cmnd))
+
+        if build_local:
+            cmnd = ['clang', '-O3', '-g3',
+                    '-Wno-unknown-attributes',
+                    '-DRUN_LOCAL=1',
+                    '-I', f'"{temp_path}"',
+                    '-o', f"{dest_path / 'local_search.out'}",
+                    f'"{source_file}"']
+            os.system(' '.join(cmnd))
+
+        # Delete the temporary files.
+        shutil.rmtree(str(temp_path))
